/*
 * Copyright (c) 2014 by David I. Bell
 * Permission is granted to use, distribute, or modify this source,
 * provided that this copyright notice remains intact.
 */

#include "dpy_priv.h"


/*
 * Set the current write location to the given row and column.
 * The position given is relative to the current window.
 * Negative numbers indicate backwards from last row or column.
 * Returns nonzero if arguments are out of bounds.
 */
int
dpymove(int row, int col)
{
	WINDOW * wp = _dpy_window_;

	int winRows;		/* number of rows in window */
	int winCols;		/* number of columns in window */

	winRows = ((wp->endWin - wp->begWin) / wp->rowDelta) + 1;
	winCols = wp->endRow - wp->begRow;

	if (row < 0)
		row += winRows;

	if (col < 0)
		col += winCols;

	/*
	 * Return 1 if trying to move out of the window.
	 */
	if (((unsigned)row >= winRows) || ((unsigned)col >= winCols))
	{
		return 1;
	}

	wp->begRow = wp->begWin + (row * wp->rowDelta);
	wp->endRow = wp->begRow + winCols;
	wp->cp = wp->begRow + col;
	wp->isFull = FALSE;

	return 0;
}

/* END CODE */
